coalib package — coala 0.9.0.dev99999999999999 documentation

# coalib package

## Subpackages

- coalib.bearlib package
  - Subpackages
    - coalib.bearlib.abstractions package
      - Submodules
      - coalib.bearlib.abstractions.ExternalBearWrap module
      - coalib.bearlib.abstractions.Linter module
      - coalib.bearlib.abstractions.SectionCreatable module
      - Module contents
    - coalib.bearlib.aspects package
      - Submodules
      - coalib.bearlib.aspects.Metadata module
      - coalib.bearlib.aspects.Redundancy module
      - coalib.bearlib.aspects.base module
      - coalib.bearlib.aspects.docs module
      - coalib.bearlib.aspects.meta module
      - coalib.bearlib.aspects.taste module
      - Module contents
    - coalib.bearlib.languages package
      - Subpackages
        - coalib.bearlib.languages.definitions package
          - Submodules
          - coalib.bearlib.languages.definitions.C module
          - coalib.bearlib.languages.definitions.CPP module
          - coalib.bearlib.languages.definitions.CSS module
          - coalib.bearlib.languages.definitions.CSharp module
          - coalib.bearlib.languages.definitions.Java module
          - coalib.bearlib.languages.definitions.JavaScript module
          - coalib.bearlib.languages.definitions.Python module
          - coalib.bearlib.languages.definitions.Vala module
          - Module contents
        - coalib.bearlib.languages.documentation package
          - Submodules
          - coalib.bearlib.languages.documentation.DocstyleDefinition module
          - coalib.bearlib.languages.documentation.DocumentationComment module
          - coalib.bearlib.languages.documentation.DocumentationExtraction module
          - Module contents
      - Submodules
      - coalib.bearlib.languages.Language module
      - coalib.bearlib.languages.LanguageDefinition module
      - Module contents
    - coalib.bearlib.naming_conventions package
      - Module contents
    - coalib.bearlib.spacing package
      - Submodules
      - coalib.bearlib.spacing.SpacingHelper module
      - Module contents
  - Module contents
- coalib.bears package
  - Subpackages
    - coalib.bears.requirements package
      - Submodules
      - coalib.bears.requirements.DistributionRequirement module
      - coalib.bears.requirements.GemRequirement module
      - coalib.bears.requirements.GoRequirement module
      - coalib.bears.requirements.JuliaRequirement module
      - coalib.bears.requirements.NpmRequirement module
      - coalib.bears.requirements.PackageRequirement module
      - coalib.bears.requirements.PipRequirement module
      - coalib.bears.requirements.RscriptRequirement module
      - Module contents
  - Submodules
  - coalib.bears.BEAR_KIND module
  - coalib.bears.Bear module
  - coalib.bears.GlobalBear module
  - coalib.bears.LocalBear module
  - Module contents
- coalib.collecting package
  - Submodules
  - coalib.collecting.Collectors module
  - coalib.collecting.Dependencies module
  - coalib.collecting.Importers module
  - Module contents
- coalib.misc package
  - Submodules
  - coalib.misc.Annotations module
  - coalib.misc.BuildManPage module
  - coalib.misc.Caching module
  - coalib.misc.CachingUtilities module
  - coalib.misc.Compatibility module
  - coalib.misc.Constants module
  - coalib.misc.ContextManagers module
  - coalib.misc.DictUtilities module
  - coalib.misc.Enum module
  - coalib.misc.Exceptions module
  - coalib.misc.MutableValue module
  - coalib.misc.Shell module
  - Module contents
- coalib.output package
  - Subpackages
    - coalib.output.printers package
      - Submodules
      - coalib.output.printers.LOG_LEVEL module
      - coalib.output.printers.ListLogPrinter module
      - coalib.output.printers.LogPrinter module
      - Module contents
  - Submodules
  - coalib.output.ConfWriter module
  - coalib.output.ConsoleInteraction module
  - coalib.output.Interactions module
  - coalib.output.JSONEncoder module
  - Module contents
- coalib.parsing package
  - Submodules
  - coalib.parsing.CliParsing module
  - coalib.parsing.ConfParser module
  - coalib.parsing.DefaultArgParser module
  - coalib.parsing.Globbing module
  - coalib.parsing.LineParser module
  - Module contents
- coalib.processes package
  - Subpackages
    - coalib.processes.communication package
      - Submodules
      - coalib.processes.communication.LogMessage module
      - Module contents
  - Submodules
  - coalib.processes.BearRunning module
  - coalib.processes.CONTROL_ELEMENT module
  - coalib.processes.LogPrinterThread module
  - coalib.processes.Processing module
  - Module contents
- coalib.results package
  - Subpackages
    - coalib.results.result_actions package
      - Submodules
      - coalib.results.result_actions.ApplyPatchAction module
      - coalib.results.result_actions.IgnoreResultAction module
      - coalib.results.result_actions.OpenEditorAction module
      - coalib.results.result_actions.PrintDebugMessageAction module
      - coalib.results.result_actions.PrintMoreInfoAction module
      - coalib.results.result_actions.ResultAction module
      - coalib.results.result_actions.ShowPatchAction module
      - Module contents
  - Submodules
  - coalib.results.AbsolutePosition module
  - coalib.results.Diff module
  - coalib.results.HiddenResult module
  - coalib.results.LineDiff module
  - coalib.results.RESULT_SEVERITY module
  - coalib.results.Result module
  - coalib.results.ResultFilter module
  - coalib.results.SourcePosition module
  - coalib.results.SourceRange module
  - coalib.results.TextPosition module
  - coalib.results.TextRange module
  - Module contents
- coalib.settings package
  - Submodules
  - coalib.settings.ConfigurationGathering module
  - coalib.settings.DocstringMetadata module
  - coalib.settings.FunctionMetadata module
  - coalib.settings.Section module
  - coalib.settings.SectionFilling module
  - coalib.settings.Setting module
  - Module contents
- coalib.testing package
  - Submodules
  - coalib.testing.BearTestHelper module
  - coalib.testing.LocalBearTestHelper module
  - Module contents

## Submodules

## coalib.coala module

`coalib.coala.` `main`()

## coalib.coala_ci module

`coalib.coala_ci.` `main`()

## coalib.coala_delete_orig module

`coalib.coala_delete_orig.` `main`(log_printer=None, section: coalib.settings.Section.Section = None)

## coalib.coala_format module

`coalib.coala_format.` `main`()

## coalib.coala_json module

`coalib.coala_json.` `main`()

## coalib.coala_main module

`coalib.coala_main.` `do_nothing`(*args)

`coalib.coala_main.` `run_coala`(console_printer=None, log_printer=None, print_results=<function <lambda>>, acquire_settings=<function fail_acquire_settings>, print_section_beginning=<function <lambda>>, nothing_done=<function <lambda>>, force_show_patch=False, arg_parser=None, arg_list=None)

  This is a main method that should be usable for almost all purposes and reduces executing coala to one function call.

  Parameters: | console_printer – Object to print messages on the console. log_printer – A LogPrinter object to use for logging. print_results – A callback that takes a LogPrinter, a section, a list of results to be printed, the file dict and the mutable file diff dict. acquire_settings – The method to use for requesting settings. It will get a parameter which is a dictionary with the settings name as key and a list containing a description in [0] and the names of the bears who need this setting in all following indexes. print_section_beginning – A callback that will be called with a section name string whenever analysis of a new section is started. nothing_done – A callback that will be called with only a log printer that shall indicate that nothing was done. force_show_patch – If set to True, a patch will be always shown. (Using ApplyPatchAction.) arg_list – The CLI argument list.
  Returns: | A dictionary containing a list of results for all analyzed sections as key.

## coalib.coala_modes module

`coalib.coala_modes.` `mode_format`()

`coalib.coala_modes.` `mode_json`(args)

`coalib.coala_modes.` `mode_non_interactive`(console_printer, args)

`coalib.coala_modes.` `mode_normal`(console_printer, log_printer)

## Module contents

The coalib package is a collection of various subpackages regarding writing, executing and editing bears. Various other packages such as formatting and settings are also included in coalib.

`coalib.` `assert_supported_version`()

`coalib.` `get_version`()